<?php

class pisol_dtt_option_pickup_location{

    private $setting = array();

    private $active_tab;

    private $this_tab = 'pickup_location';

    private $tab_name = "Pickup Locations";

    private $setting_key = 'pisol_dtt_pickup_location';

    function __construct(){

        $this->active_tab = (isset($_GET['tab'])) ? $_GET['tab'] : 'default';

        $this->settings = array(
                array('field'=>'pi_pickup_address_1', 'label'=>__('Pickup location one','pisol-dtt'),'desc'=>'Type your pickup address in this text box', 'type'=>'textarea'), 
                array('field'=>'pi_pickup_address_2', 'label'=>__('Pickup location two','pisol-dtt'),'desc'=>'Type your pickup address in this text box', 'type'=>'textarea'), 
            );
        

        if($this->this_tab == $this->active_tab){
            add_action('pisol_dtt_tab_content', array($this,'tab_content'));
        }

        add_action('pisol_dtt_tab', array($this,'tab'),1);

        add_action( 'admin_enqueue_scripts', array($this,'admin_script_date_time') );
        
        add_action('dtt_pickup_location', array($this,'select_pickup_location'));

        /* validating field */
        add_action('woocommerce_checkout_process', array($this,'checkout_field_process'));
        
        /* Update order meta data */
        add_action( 'woocommerce_checkout_update_order_meta', array($this,'update_order_meta') );

        //Display field value on the order edit page
        add_action( 'woocommerce_admin_order_data_after_shipping_address', array($this,'admin_order_meta'), 10, 1 );
    
        // Displays order meta on order detial page on front end
        add_action( 'woocommerce_order_details_after_order_table_items', array($this,'user_order_meta'), 10, 1 );
        
         //include the custom order meta to woocommerce mail
         add_action( "woocommerce_email_after_order_table", array($this,"email_after_order_table"), 10, 1);
        

        $this->register_settings();
    }

    function register_settings(){   

        foreach($this->settings as $setting){
                register_setting( $this->setting_key, $setting['field']);
        }
    
    }

    function tab(){
        ?>
        <a class="nav-tab <?php echo $this->active_tab == $this->this_tab || '' ? 'nav-tab-active' : ''; ?>" href="<?php echo admin_url( 'admin.php?page='.$_GET['page'].'&tab='.$this->this_tab ); ?>">
            <?php _e( $this->tab_name, 'pisol-dtt' ); ?> 
        </a>
        <?php
    }

    function tab_content(){
       ?>
        <form method="post" action="options.php"  class="pisol-setting-form">
        <?php settings_fields( $this->setting_key ); ?>
        <div class="pisol_grid">
        <?php
            foreach($this->settings as $setting){
                new pisol_dtt_class_form($setting, $this->setting_key);
            }
        ?>
        </div>
        <div class="postbox pisol-offer" style="margin-right:10px;">
        <div class="inside" style="text-align:center;">
        <h2 style="color:#fff;">Pro version allows you to add <i><u>Unlimited</u></i> number of pickup locations<h2>
        <a class="button button-primary" href="https://www.piwebsolution.com/cart/?add-to-cart=621" target="_blank">Click to Buy Now</a>
        </div>
        </div>
        <?php submit_button(); ?>
        </form>
       <?php
    }

    function admin_script_date_time(){
        wp_enqueue_script( 'pi-dtt-custom',plugins_url('admin/js/custom.js', __FILE__) );
    }

    function select_pickup_location(){
       $address1 = get_option('pi_pickup_address_1', "");
       $address2 = get_option('pi_pickup_address_2', "");

       if(empty($address1) && empty($address2)){
           return false;
       }
       echo '<div id="pisol-pickup-locations" style="grid-column: span 2;">';
       echo '<label>'.__("Select a pickup location",'pisol-dtt').'</label>';
       echo '<div style="display:flex;">';
       if(!empty($address1)){
        echo '<div class="pisol-pickup-add"><input type="radio" name="pickup_location" class="pisol-location-radio" value="pi_pickup_address_1" id="pi_pickup_address_1"><label class="pisol-location" for="pi_pickup_address_1">'.$address1.'</label></div>';
       }
       if(!empty($address2)){
        echo '<div class="pisol-pickup-add"><input type="radio" name="pickup_location" class="pisol-location-radio" value="pi_pickup_address_2" id="pi_pickup_address_2"><label  class="pisol-location" for="pi_pickup_address_2">'.$address2.'</label></div>';
       }
       echo '</div>';
       echo '</div>';
    }
   
    function checkout_field_process(){
        if ( isset($_POST['pi_delivery_type']) && $_POST['pi_delivery_type'] == 'pickup' ){

            if(empty($_POST['pickup_location'])){
                wc_add_notice( __( 'Please select a pickup location','pisol-dtt' ), 'error' );
            }

        }
    } 

    function update_order_meta($order_id){
        if(!empty($_POST['pickup_location']) && isset($_POST['pi_delivery_type']) && $_POST['pi_delivery_type'] == 'pickup'){
            $pickup_address = get_option($_POST['pickup_location'], "");

            update_post_meta( $order_id, 'pickup_location', sanitize_text_field($pickup_address) );

        }
    }

    function admin_order_meta($order){
        $order_id = version_compare( WC_VERSION, '3.0.0', '<' ) ? $order->id : $order->get_id();
        $location  = get_post_meta( $order_id, 'pickup_location', true );
        if($location != ''){
            echo '<p><strong>'.__('Pickup location','pisol-dtt').':</strong> ' . $location . '</p>';
        }  
    }

    function user_order_meta($order){
        $order_id = version_compare( WC_VERSION, '3.0.0', '<' ) ? $order->id : $order->get_id();
        $location  = get_post_meta( $order_id, 'pickup_location', true );
        if($location != ''){
            echo '<p><strong>'.__('Pickup location','pisol-dtt').':</strong> ' . $location . '</p>';
        } 
    }

    function email_after_order_table($order){
        $order_id = version_compare( WC_VERSION, '3.0.0', '<' ) ? $order->id : $order->get_id();
        $location  = get_post_meta( $order_id, 'pickup_location', true );
        if($location != ''){
            echo '<p><strong>'.__('Pickup location','pisol-dtt').':</strong> ' . $location . '</p>';
        } 
    }
}

/* if we have pro version setting for time tab then we can disable this */
add_action('pisol_dtt_option', new pisol_dtt_option_pickup_location(),3);

add_action( 'wp_enqueue_scripts', 'pisol_dtt_pickup_location_script' );

function pisol_dtt_pickup_location_script(){
    if (  is_checkout() ) {
        $delivery_date = '
        jQuery(function($){

            $("#pi_delivery_type_pickup, #pi_delivery_type_delivery").on("change", function(){
                var value = $(this).val();
                
                if(value == "pickup"){
                    $("#pisol-pickup-locations").fadeIn();
                    
                }else{
                    $("#pisol-pickup-locations").fadeOut();
                }
            });

        });
        ';
        wp_add_inline_script('jquery', $delivery_date);
    }
}