<?php
/*
Plugin Name: PI Woocommerce order date time and type
Plugin URI: https://woo-restaurant.com/
Description: Set order delivery date, time and type for Woocommerce
Version: 1.2.5
Author: PI Websolution
Author URI: piwebsolution.com
Text Domain: pisol-dtt
*/

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

define('PISOL_DTT_URL', plugin_dir_url(__FILE__));
define('PISOL_DTT_PATH', plugin_dir_path( __FILE__ ));
define('PISOL_DTT_BASE', plugin_basename(__FILE__));


/* 
    Making sure woocommerce is there 
*/
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

if(!is_plugin_active( 'woocommerce/woocommerce.php')){
    function dtt_error_notice() {
        ?>
        <div class="error notice">
            <p><?php _e( 'Please Install and Activate WooCommerce plugin, without that this plugin cant work', 'pisol-restautant-menu' ); ?></p>
        </div>
        <?php
    }
    add_action( 'admin_notices', 'dtt_error_notice' );
    deactivate_plugins(plugin_basename(__FILE__));
    return;
}

/* This adds menu link */
include_once PISOL_DTT_PATH.'menu.php';

/* This adds tab in menu page first tab */
include_once PISOL_DTT_PATH.'options.php';

/* This adds 2nd tab in menu page */
include_once PISOL_DTT_PATH.'options-time.php';
include_once PISOL_DTT_PATH.'options-date.php';

if (!class_exists('pisol_dtt_pro_option_pickup_location')) {
    include_once PISOL_DTT_PATH.'options-pickup.php';
}

/* 
    core function
*/
class pi_order_date_time_type{

    public $type = true;
    public $datetime = true;
    public $pi_preorder_days = 10;
    public $pi_pickup_label;
    public $pi_delivery_label;
    
    function __construct(){
        add_action( 'woocommerce_checkout_before_customer_details',array($this,'adding_field_checkout'));
        
        /* validating field */
        add_action('woocommerce_checkout_process', array($this,'checkout_field_process'));
    
        /* Update order meta data */
        add_action( 'woocommerce_checkout_update_order_meta', array($this,'update_order_meta') );
    
        //Display field value on the order edit page
        add_action( 'woocommerce_admin_order_data_after_shipping_address', array($this,'admin_order_meta'), 10, 1 );
    
        // Displays order meta on order detial page on front end
        add_action( 'woocommerce_order_details_after_order_table_items', array($this,'user_order_meta'), 10, 1 );
    
        //include the custom order meta to woocommerce mail
        add_action( "woocommerce_email_after_order_table", array($this,"email_after_order_table"), 10, 1);
        
        add_action( 'init', array($this,'wc_init') );

        $this->type = get_option('pi_type', true);
        $this->datetime = get_option('pi_datetime', true);
        $this->pi_preorder_days = abs(get_option('pi_preorder_days', 10));
        $this->pi_pickup_label = get_option('pi_pickup_label',__('Pickup','pisol-dtt'));
        $this->pi_delivery_label = get_option('pi_delivery_label',__('Delivery','pisol-dtt'));
        $this->pi_default_type = get_option('pi_default_type','delivery');
        
    }

    function wc_init(){
       
        add_action( 'wp_enqueue_scripts', array($this,'add_scripts') ); 
       
    }

    function adding_field_checkout($field){
        echo '<div id="pi_checkout_field">';
        if($this->type):
        woocommerce_form_field( 'pi_delivery_type', array(
        
        'type'          => 'radio',
        
        'required'		=>	'true',
        
        'class'         => array('pi_delivery_type'),
        
        'label'         => __('Delivery Type','pisol-dtt'),
        
        'placeholder'   => __('Select delivery type','pisol-dtt'),
        
        'default'		=> $this->pi_default_type,
        
        'checked'		=> 'checked',
        
        'options'		=> array(
         'delivery' => $this->pi_delivery_label, 
        'pickup' => $this->pi_pickup_label, 
        )
       
        
        ));
        endif;

        if($this->datetime):
        woocommerce_form_field( 'pi_delivery_date', array(

            'type'          => 'text',
            
            'required'		=>	'true',
            
            'class'         => array('pi_delivery_date'),
            
            'label'         => __('Delivery date','pisol-dtt'),
            
            'placeholder'   => __('Date','pisol-dtt'),
            
            'custom_attributes' => array('readonly'=>'readonly'),
            
            ));

        woocommerce_form_field( 'pi_delivery_time', array(

                'type'          => 'text',
                
                'required'		=>	'true',
                
                'class'         => array('pi_delivery_time'),
                
                'label'         =>  __('Delivery time','pisol-dtt'),
                
                'placeholder'   => __('Time','pisol-dtt'),
                  
                'custom_attributes' => array('readonly'=>'readonly', 'disabled'=>'disabled'),
                ));
        endif;

        do_action('dtt_pickup_location');

        echo '</div>';
    }

    function checkout_field_process(){
        if($this->datetime):
        if (empty( $_POST['pi_delivery_date']) || !isset($_POST['pi_delivery_date']) )
        wc_add_notice( __( 'Enter your desired delivery date.','pisol-dtt' ), 'error' );

        if (empty($_POST['pi_delivery_time']) || !isset($_POST['pi_delivery_time']) )
        wc_add_notice( __( 'Enter your desired delivery time.','pisol-dtt' ), 'error' );
        endif;
    }

    function update_order_meta($order_id){
        if($this->datetime):
            if ( ! empty( $_POST['pi_delivery_date'] ) ) {
                update_post_meta( $order_id, 'pi_delivery_date', sanitize_text_field( $_POST['pi_delivery_date'] ) );
            }
                
            if ( ! empty( $_POST['pi_delivery_time'] ) ) {
                update_post_meta( $order_id, 'pi_delivery_time', sanitize_text_field( $_POST['pi_delivery_time'] ) );
            }
        endif;
        
        if($this->type):
        if ( ! empty( $_POST['pi_delivery_type'] ) ) {
            update_post_meta( $order_id, 'pi_delivery_type', sanitize_text_field($_POST['pi_delivery_type']) );
        }
        endif;
            
    }

    function admin_order_meta($order){

        $order_id = version_compare( WC_VERSION, '3.0.0', '<' ) ? $order->id : $order->get_id();

        if(get_post_meta( $order_id, 'pi_delivery_type', true )=='pickup'){
            $order_delivery_type =  $this->pi_pickup_label; 
        } 
        else 
        { 
            $order_delivery_type = $this->pi_delivery_label;
        }
        if($this->datetime):
        echo '<p><strong>'.__('Delivery date','pisol-dtt').':</strong> ' . get_post_meta( $order_id, 'pi_delivery_date', true ) . '</p>';

        echo '<p><strong>'.__('Delivery time','pisol-dtt').':</strong> ' . get_post_meta( $order_id, 'pi_delivery_time', true ) . '</p>';
        endif;

        if($this->type):
        echo '<p><strong>'.__('Delivery type','pisol-dtt').':</strong> ' . $order_delivery_type . '</p>';
        endif;
    }

    function user_order_meta($order){
        $order_id = version_compare( WC_VERSION, '3.0.0', '<' ) ? $order->id : $order->get_id();
        
        if(get_post_meta( $order_id, 'pi_delivery_type', true )=='pickup'){
            $order_delivery_type =   $this->pi_pickup_label; 
        } 
        else 
        { 
            $order_delivery_type = $this->pi_delivery_label;
        }

        if($this->datetime):
        echo '<p><strong>'.__('Delivery date','pisol-dtt').':</strong> ' . get_post_meta( $order_id, 'pi_delivery_date', true ) . '</p>';

        echo '<p><strong>'.__('Delivery time','pisol-dtt').':</strong> ' . get_post_meta( $order_id, 'pi_delivery_time', true ) . '</p>';
        endif; 

        if($this->type):
        echo '<p><strong>'.__('Delivery type','pisol-dtt').':</strong> ' . $order_delivery_type . '</p>';
        endif;
    }

    function email_after_order_table($order){
        $order_id = version_compare( WC_VERSION, '3.0.0', '<' ) ? $order->id : $order->get_id();
        
        if(get_post_meta( $order_id, 'pi_delivery_type', true )=='pickup'){
            $order_delivery_type =   $this->pi_pickup_label; 
        } 
        else 
        { 
            $order_delivery_type = $this->pi_delivery_label;
        }

        if($this->datetime):
        echo '<br /><br /><p><strong>'.__('Delivery date','pisol-dtt').':</strong> ' . get_post_meta( $order_id, 'pi_delivery_date', true ) . '</p>';

        echo '<p><strong>'.__('Delivery time','pisol-dtt').':</strong> ' . get_post_meta( $order_id, 'pi_delivery_time', true ) . '</p>';
        endif;

        if($this->type):
        echo '<p><strong>'.__('Delivery type','pisol-dtt').':</strong> ' . $order_delivery_type . '</p>';
        endif;
    }

    function add_scripts(){
        if (  is_checkout() ) {
            wp_enqueue_style('pi_dtt_stylesheet', plugins_url('css/style.css', __FILE__));

            wp_enqueue_script( 'pi-dtt-custom',plugins_url('js/custom.js', __FILE__) );
            
        }
    }
}

new pi_order_date_time_type();


